@@ -3,6 +3,7 @@ package cmd
 import (
 	"context"
 	"os"
+	"sync"
 
 	"github.com/mattn/go-isatty"
 	"github.com/spf13/cobra"
@@ -17,6 +18,9 @@ import (
 
 var exitCode int
 
+// commandMutex protects concurrent access to rootCmd's command list
+var commandMutex sync.Mutex
+
 // rootCmd represents the base command when called without any subcommands
 var rootCmd = &cobra.Command{
 	Use:   "steampipe [--version] [--help] COMMAND [args]",
@@ -80,11 +84,21 @@ func InitCmd() {
 
 func hideRootFlags(flags ...string) {
 	for _, flag := range flags {
-		rootCmd.Flag(flag).Hidden = true
+		if f := rootCmd.Flag(flag); f != nil {
+			f.Hidden = true
+		}
 	}
 }
 
+// AddCommands adds all subcommands to the root command.
+//
+// This function is thread-safe and can be called concurrently.
+// However, it is typically only called during CLI initialization
+// in a single-threaded context.
 func AddCommands() {
+	commandMutex.Lock()
+	defer commandMutex.Unlock()
+
 	// explicitly initialise commands here rather than in init functions to allow us to handle errors from the config load
 	rootCmd.AddCommand(
 		pluginCmd(),
@@ -96,6 +110,17 @@ func AddCommands() {
 	)
 }
 
+// ResetCommands removes all subcommands from the root command.
+//
+// This function is thread-safe and can be called concurrently.
+// It is primarily used for testing.
+func ResetCommands() {
+	commandMutex.Lock()
+	defer commandMutex.Unlock()
+
+	rootCmd.ResetCommands()
+}
+
 func Execute() int {
 	utils.LogTime("cmd.root.Execute start")
 	defer utils.LogTime("cmd.root.Execute end")
