@@ -6,6 +6,7 @@ import (
 	"log"
 	"strings"
 	"sync"
+	"sync/atomic"
 
 	"github.com/jackc/pgx/v5/pgconn"
 	"github.com/jackc/pgx/v5/pgxpool"
@@ -42,20 +43,24 @@ type DbClient struct {
 
 	// map of database sessions, keyed to the backend_pid in postgres
 	// used to update session search path where necessary
-	// TODO: there's no code which cleans up this map when connections get dropped by pgx
-	// https://github.com/turbot/steampipe/issues/3737
+	// Session lifecycle: entries are added when connections are established and automatically
+	// removed via a pgxpool BeforeClose callback when connections are closed by the pool.
+	// This prevents memory accumulation from stale connection entries (see issue #3737)
 	sessions map[uint32]*db_common.DatabaseSession
 
 	// allows locked access to the 'sessions' map
-	sessionsMutex *sync.Mutex
+	sessionsMutex    *sync.Mutex
+	sessionsLockFlag atomic.Bool
 
 	// if a custom search path or a prefix is used, store it here
 	customSearchPath []string
 	searchPathPrefix []string
+	// allows locked access to customSearchPath and searchPathPrefix
+	searchPathMutex *sync.RWMutex
 	// the default user search path
 	userSearchPath []string
 	// disable timing - set whilst in process of querying the timing
-	disableTiming        bool
+	disableTiming        atomic.Bool
 	onConnectionCallback DbConnectionCallback
 }
 
@@ -69,6 +74,7 @@ func NewDbClient(ctx context.Context, connectionString string, opts ...ClientOpt
 		parallelSessionInitLock: semaphore.NewWeighted(constants.MaxParallelClientInits),
 		sessions:                make(map[uint32]*db_common.DatabaseSession),
 		sessionsMutex:           &sync.Mutex{},
+		searchPathMutex:         &sync.RWMutex{},
 		connectionString:        connectionString,
 	}
 
@@ -134,7 +140,7 @@ func (c *DbClient) loadServerSettings(ctx context.Context) error {
 
 func (c *DbClient) shouldFetchTiming() bool {
 	// check for override flag (this is to prevent timing being fetched when we read the timing metadata table)
-	if c.disableTiming {
+	if c.disableTiming.Load() {
 		return false
 	}
 	// only fetch timing if timing flag is set, or output is JSON
@@ -147,6 +153,37 @@ func (c *DbClient) shouldFetchVerboseTiming() bool {
 		(viper.GetString(pconstants.ArgOutput) == constants.OutputFormatJSON)
 }
 
+// lockSessions acquires the sessionsMutex and tracks ownership for tryLock compatibility.
+func (c *DbClient) lockSessions() {
+	if c.sessionsMutex == nil {
+		return
+	}
+	c.sessionsLockFlag.Store(true)
+	c.sessionsMutex.Lock()
+}
+
+// sessionsTryLock attempts to acquire the sessionsMutex without blocking.
+// Returns false if the lock is already held.
+func (c *DbClient) sessionsTryLock() bool {
+	if c.sessionsMutex == nil {
+		return false
+	}
+	// best-effort: only one contender sets the flag and proceeds to lock
+	if !c.sessionsLockFlag.CompareAndSwap(false, true) {
+		return false
+	}
+	c.sessionsMutex.Lock()
+	return true
+}
+
+func (c *DbClient) sessionsUnlock() {
+	if c.sessionsMutex == nil {
+		return
+	}
+	c.sessionsMutex.Unlock()
+	c.sessionsLockFlag.Store(false)
+}
+
 // ServerSettings returns the settings of the steampipe service that this DbClient is connected to
 //
 // Keep in mind that when connecting to pre-0.21.x servers, the server_settings data is not available. This is expected.
@@ -167,7 +204,10 @@ func (c *DbClient) Close(context.Context) error {
 	c.closePools()
 	// nullify active sessions, since with the closing of the pools
 	// none of the sessions will be valid anymore
+	// Acquire mutex to prevent concurrent access to sessions map
+	c.lockSessions()
 	c.sessions = nil
+	c.sessionsUnlock()
 
 	return nil
 }
@@ -241,8 +281,12 @@ func (c *DbClient) ResetPools(ctx context.Context) {
 	log.Println("[TRACE] db_client.ResetPools start")
 	defer log.Println("[TRACE] db_client.ResetPools end")
 
-	c.userPool.Reset()
-	c.managementPool.Reset()
+	if c.userPool != nil {
+		c.userPool.Reset()
+	}
+	if c.managementPool != nil {
+		c.managementPool.Reset()
+	}
 }
 
 func (c *DbClient) buildSchemasQuery(schemas ...string) string {
