@@ -61,6 +61,21 @@ func (c *DbClient) establishConnectionPool(ctx context.Context, overrides client
 	if c.onConnectionCallback != nil {
 		config.AfterConnect = c.onConnectionCallback
 	}
+	// Clean up session map when connections are closed to prevent memory leak
+	// Reference: https://github.com/turbot/steampipe/issues/3737
+	config.BeforeClose = func(conn *pgx.Conn) {
+		if conn != nil && conn.PgConn() != nil {
+			backendPid := conn.PgConn().PID()
+			// Best-effort cleanup: do not block pool.Close() if sessions lock is busy.
+			if c.sessionsTryLock() {
+				// Check if sessions map has been nil'd by Close()
+				if c.sessions != nil {
+					delete(c.sessions, backendPid)
+				}
+				c.sessionsUnlock()
+			}
+		}
+	}
 	// set an app name so that we can track database connections from this Steampipe execution
 	// this is used to determine whether the database can safely be closed
 	config.ConnConfig.Config.RuntimeParams = map[string]string{
