@@ -7,13 +7,13 @@ import (
 	"strings"
 
 	"github.com/jackc/pgx/v5"
-	"github.com/turbot/pipe-fittings/utils"
+	"github.com/turbot/pipe-fittings/v2/utils"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
-	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/db/db_common"
-	"github.com/turbot/steampipe/pkg/introspection"
-	"github.com/turbot/steampipe/pkg/statushooks"
-	"github.com/turbot/steampipe/pkg/steampipeconfig"
+	"github.com/turbot/steampipe/v2/pkg/constants"
+	"github.com/turbot/steampipe/v2/pkg/db/db_common"
+	"github.com/turbot/steampipe/v2/pkg/introspection"
+	"github.com/turbot/steampipe/v2/pkg/statushooks"
+	"github.com/turbot/steampipe/v2/pkg/steampipeconfig"
 )
 
 // dropLegacyInternalSchema looks for a schema named 'internal'
