@@ -1,8 +1,8 @@
 package metaquery
 
 import (
-	pconstants "github.com/turbot/pipe-fittings/constants"
-	"github.com/turbot/steampipe/pkg/constants"
+	pconstants "github.com/turbot/pipe-fittings/v2/constants"
+	"github.com/turbot/steampipe/v2/pkg/constants"
 )
 
 type metaQueryArg struct {
