@@ -15,7 +15,7 @@ import (
 	"github.com/turbot/pipe-fittings/v2/modconfig"
 	"github.com/turbot/pipe-fittings/v2/pipes"
 	"github.com/turbot/pipe-fittings/v2/querydisplay"
-	"github.com/turbot/pipe-fittings/v2/queryresult"
+	pqueryresult "github.com/turbot/pipe-fittings/v2/queryresult"
 	"github.com/turbot/pipe-fittings/v2/steampipeconfig"
 	"github.com/turbot/pipe-fittings/v2/utils"
 	"github.com/turbot/steampipe/v2/pkg/cmdconfig"
@@ -25,6 +25,7 @@ import (
 	"github.com/turbot/steampipe/v2/pkg/error_helpers"
 	"github.com/turbot/steampipe/v2/pkg/interactive"
 	"github.com/turbot/steampipe/v2/pkg/query"
+	"github.com/turbot/steampipe/v2/pkg/query/queryresult"
 	"github.com/turbot/steampipe/v2/pkg/snapshot"
 )
 
@@ -37,9 +38,11 @@ func RunInteractiveSession(ctx context.Context, initData *query.InitData) error
 
 	// print the data as it comes
 	for r := range result.Streamer.Results {
+		// wrap the result from pipe-fittings with our wrapper that has idempotent Close
+		wrapped := queryresult.WrapResult(r)
 		rowCount, _ := querydisplay.ShowOutput(ctx, r)
 		// show timing
-		display.DisplayTiming(r, rowCount)
+		display.DisplayTiming(wrapped, rowCount)
 		// signal to the resultStreamer that we are done with this chunk of the stream
 		result.Streamer.AllResultsRead()
 	}
@@ -47,12 +50,22 @@ func RunInteractiveSession(ctx context.Context, initData *query.InitData) error
 }
 
 func RunBatchSession(ctx context.Context, initData *query.InitData) (int, error) {
+	if initData == nil {
+		return 0, fmt.Errorf("initData cannot be nil")
+	}
+
 	// start cancel handler to intercept interrupts and cancel the context
 	// NOTE: use the initData Cancel function to ensure any initialisation is cancelled if needed
 	contexthelpers.StartCancelHandler(initData.Cancel)
 
-	// wait for init
-	<-initData.Loaded
+	// wait for init, respecting context cancellation
+	select {
+	case <-initData.Loaded:
+		// initialization complete, continue
+	case <-ctx.Done():
+		// context cancelled before initialization completed
+		return 0, ctx.Err()
+	}
 
 	if err := initData.Result.Error; err != nil {
 		return 0, err
@@ -61,6 +74,11 @@ func RunBatchSession(ctx context.Context, initData *query.InitData) (int, error)
 	// display any initialisation messages/warnings
 	initData.Result.DisplayMessages()
 
+	// validate that Client is not nil
+	if initData.Client == nil {
+		return 0, fmt.Errorf("client is required but not initialized")
+	}
+
 	// if there is a custom search path, wait until the first connection of each plugin has loaded
 	if customSearchPath := initData.Client.GetCustomSearchPath(); customSearchPath != nil {
 		if err := connection_sync.WaitForSearchPathSchemas(ctx, initData.Client, customSearchPath); err != nil {
@@ -81,6 +99,12 @@ func executeQueries(ctx context.Context, initData *query.InitData) int {
 	utils.LogTime("queryexecute.executeQueries start")
 	defer utils.LogTime("queryexecute.executeQueries end")
 
+	// Check if Client is nil - this can happen if initialization failed
+	if initData.Client == nil {
+		error_helpers.ShowWarning("cannot execute queries: database client is not initialized")
+		return len(initData.Queries)
+	}
+
 	// failures return the number of queries that failed and also the number of rows that
 	// returned errors
 	failures := 0
@@ -123,6 +147,8 @@ func executeQuery(ctx context.Context, initData *query.InitData, resolvedQuery *
 	rowErrors := 0 // get the number of rows that returned an error
 	// print the data as it comes
 	for r := range resultsStreamer.Results {
+		// wrap the result from pipe-fittings with our wrapper that has idempotent Close
+		wrapped := queryresult.WrapResult(r)
 
 		// if the output format is snapshot or export is set or share/snapshot args are set, we need to generate a snapshot
 		if needSnapshot() {
@@ -133,7 +159,7 @@ func executeQuery(ctx context.Context, initData *query.InitData, resolvedQuery *
 
 			// re-generate the query result from the snapshot. since the row stream in the actual queryresult has been exhausted(while generating the snapshot),
 			// we need to re-generate it for other output formats
-			newQueryResult, err := snapshot.SnapshotToQueryResult[queryresult.TimingContainer](snap, initData.StartTime)
+			newQueryResult, err := snapshot.SnapshotToQueryResult[pqueryresult.TimingContainer](snap, initData.StartTime)
 			if err != nil {
 				return err, 0
 			}
@@ -177,7 +203,7 @@ func executeQuery(ctx context.Context, initData *query.InitData, resolvedQuery *
 			// if other output formats are also needed, we call the querydisplay using the re-generated query result
 			rowCount, _ := querydisplay.ShowOutput(ctx, newQueryResult)
 			// show timing
-			display.DisplayTiming(r, rowCount)
+			display.DisplayTiming(wrapped, rowCount)
 
 			// signal to the resultStreamer that we are done with this result
 			resultsStreamer.AllResultsRead()
@@ -187,7 +213,7 @@ func executeQuery(ctx context.Context, initData *query.InitData, resolvedQuery *
 		// for other output formats, we call the querydisplay code in pipe-fittings
 		rowCount, rowErrs := querydisplay.ShowOutput(ctx, r)
 		// show timing
-		display.DisplayTiming(r, rowCount)
+		display.DisplayTiming(wrapped, rowCount)
 
 		// signal to the resultStreamer that we are done with this result
 		resultsStreamer.AllResultsRead()
