@@ -9,17 +9,17 @@ import (
 	"github.com/hashicorp/go-version"
 	"github.com/turbot/go-kit/helpers"
 	typehelpers "github.com/turbot/go-kit/types"
-	"github.com/turbot/pipe-fittings/constants"
-	"github.com/turbot/pipe-fittings/error_helpers"
-	"github.com/turbot/pipe-fittings/filepaths"
-	"github.com/turbot/pipe-fittings/modconfig"
-	"github.com/turbot/pipe-fittings/ociinstaller"
-	poptions "github.com/turbot/pipe-fittings/options"
-	"github.com/turbot/pipe-fittings/plugin"
-	"github.com/turbot/pipe-fittings/versionfile"
-	"github.com/turbot/pipe-fittings/workspace_profile"
+	"github.com/turbot/pipe-fittings/v2/constants"
+	"github.com/turbot/pipe-fittings/v2/error_helpers"
+	"github.com/turbot/pipe-fittings/v2/filepaths"
+	"github.com/turbot/pipe-fittings/v2/modconfig"
+	"github.com/turbot/pipe-fittings/v2/ociinstaller"
+	poptions "github.com/turbot/pipe-fittings/v2/options"
+	"github.com/turbot/pipe-fittings/v2/plugin"
+	"github.com/turbot/pipe-fittings/v2/versionfile"
+	"github.com/turbot/pipe-fittings/v2/workspace_profile"
 	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
-	"github.com/turbot/steampipe/pkg/options"
+	"github.com/turbot/steampipe/v2/pkg/options"
 )
 
 // SteampipeConfig is a struct to hold Connection map and Steampipe options
@@ -118,9 +118,6 @@ func (c *SteampipeConfig) SetOptions(opts poptions.Options) (errorsAndWarnings e
 	return errorsAndWarnings
 }
 
-var defaultCacheEnabled = true
-var defaultTTL = 300
-
 func (c *SteampipeConfig) String() string {
 	var connectionStrings []string
 	for _, c := range c.Connections {
