@@ -1,6 +1,13 @@
 package task
 
+import "context"
+
+type TaskRunOption func(o *taskRunConfig)
+
+type HookFn func(context.Context)
+
 type taskRunConfig struct {
+	preHooks       []HookFn
 	runUpdateCheck bool
 }
 
@@ -10,10 +17,14 @@ func newRunConfig() *taskRunConfig {
 	}
 }
 
-type TaskRunOption func(o *taskRunConfig)
-
 func WithUpdateCheck(run bool) TaskRunOption {
 	return func(o *taskRunConfig) {
 		o.runUpdateCheck = run
 	}
 }
+
+func WithPreHook(f HookFn) TaskRunOption {
+	return func(o *taskRunConfig) {
+		o.preHooks = append(o.preHooks, f)
+	}
+}
