@@ -1,14 +1,17 @@
-//go:build darwin || linux
-// +build darwin linux
-
 package utils
 
 import (
 	"fmt"
 
 	psutils "github.com/shirou/gopsutil/process"
+	"github.com/turbot/pipe-fittings/v2/utils"
 )
 
+// TODO We should look to use pipe-fittings/v2/utils.PidExists instead of this function.
+// Currently when using the pipe-fittings function, we are seeing some errors with the pids not being found
+// resulting in unsuccessful service shutdowns.
+// https://github.com/turbot/steampipe/issues/4487
+
 // PidExists scans through the list of PIDs in the system
 // and checks for the `targetPID`.
 //
@@ -17,8 +20,8 @@ import (
 // is a child of the source of the signal - which may be the case then starting
 // implicit services
 func PidExists(targetPid int) (bool, error) {
-	LogTime("utils.PidExists start")
-	defer LogTime("utils.PidExists end")
+	utils.LogTime("utils.PidExists start")
+	defer utils.LogTime("utils.PidExists end")
 
 	process, err := FindProcess(targetPid)
 	found := process != nil
@@ -28,8 +31,8 @@ func PidExists(targetPid int) (bool, error) {
 // FindProcess tries to find the process with the given pid
 // returns nil if the process could not be found
 func FindProcess(targetPid int) (*psutils.Process, error) {
-	LogTime("utils.FindProcess start")
-	defer LogTime("utils.FindProcess end")
+	utils.LogTime("utils.FindProcess start")
+	defer utils.LogTime("utils.FindProcess end")
 
 	pids, err := psutils.Pids()
 	if err != nil {
@@ -37,9 +40,9 @@ func FindProcess(targetPid int) (*psutils.Process, error) {
 	}
 	for _, pid := range pids {
 		if targetPid == int(pid) {
+			//nolint: gosec	// target pdi will be 32 bit
 			process, err := psutils.NewProcess(int32(targetPid))
 			if err != nil {
-				// if we fail to create a process for the pid, just treat it as if we can't find the process
 				return nil, nil
 			}
 
